SignInSignUpWordings class

Constructors

SignInSignUpWordings({String cancelButtonText = 'Cancel', String signInTitle = 'Sign in to Archer', String signInButtonText = 'Sign in', String signInAppBarTitle = 'Sign in', String sendACodeButtonText = 'Send a code', String continueWithPassword = 'Continue with Password', String forgotPasswordButtonText = 'Forgot Password?', String firstName = 'First Name', String lastName = 'Last Name', String emailOrPhone = 'Email or Phone', String password = 'Password', String confirmPassword = 'Confirm Password', String forgotPassword = 'Forgot Password?', String continueWord = 'Continue', String errorMessageTextFieldEmpty = 'Please enter some text', String errorMessageTextFielEmailOrPhone = 'The Login is not in the correct format', String errorMessageTextFieldPassword = 'the password is not strong enough', String errorMessageTextFieldPasswordWeak = "Weak. Your password is unsafe, add more letters, special characters and numbers", String errorMessageTextFieldPasswordAverage = 'Average. Your password is not safe enough. Try to add more special characters and numbers', String errorMessageTextFieldPasswordStrong = 'Strong. Your password is safe!', String errorMessageTextFieldConfirmPassword = 'The passwords you have entered do not match', String checkCodeTitle = 'Enter the digit code:', String checkCodeSubtitle = 'Sent to ', String checkCodePhoneSubtitle = 'Texted to ', String apiErrorTokenMessage = 'Invalid Company Token', String resetPasswordTitle = "Reset password", String resetPasswordSubtitle = "We will send you a link to reset your password.", String resetPasswordButton = "Send link to reset password", String changePasswordTitle = "Create a new password", String changePasswordButton = "Save new password", String signInWithPasskeyButtonText = 'Sign in with Passkey', String setupPasskeyTitle = 'Set up a passkey', String setupPasskeySubtitle = 'Sign in faster and more securely next time with Face ID, Touch ID, or a security key — no password needed.', String setupPasskeyButtonText = 'Set up passkey', String setupPasskeyLaterButtonText = 'Maybe later'})

Properties

apiErrorTokenMessage String
final
cancelButtonText String
final
changePasswordButton String
final
changePasswordTitle String
final
checkCodePhoneSubtitle String
final
checkCodeSubtitle String
final
checkCodeTitle String
final
confirmPassword String
final
continueWithPassword String
final
continueWord String
final
emailOrPhone String
final
errorMessageTextFieldConfirmPassword String
final
errorMessageTextFieldEmpty String
final
errorMessageTextFieldPassword String
final
errorMessageTextFieldPasswordAverage String
final
errorMessageTextFieldPasswordStrong String
final
errorMessageTextFieldPasswordWeak String
final
errorMessageTextFielEmailOrPhone String
final
firstName String
final
forgotPassword String
final
forgotPasswordButtonText String
final
hashCode int
The hash code for this object.
no setterinherited
lastName String
final
password String
final
resetPasswordButton String
final
resetPasswordSubtitle String
final
resetPasswordTitle String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendACodeButtonText String
final
setupPasskeyButtonText String
final
setupPasskeyLaterButtonText String
final
setupPasskeySubtitle String
final
setupPasskeyTitle String
final
signInAppBarTitle String
final
signInButtonText String
final
signInTitle String
final
signInWithPasskeyButtonText String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited